import time
from ewokscore import Task


class SumTask(
    Task,
    input_names=["a"],
    optional_input_names=["b", "delay"],
    output_names=["result"],
):
    """Add two numbers"""

    def run(self):
        result = self.inputs.a + self.get_input_value("b", 0)
        time.sleep(self.get_input_value("delay", 0))
        self.outputs.result = result


class SumTask1(
    Task,
    input_names=["a"],
    optional_input_names=["b", "delay"],
    output_names=["result"],
):
    """Add two numbers"""

    def run(self):
        result = self.inputs.a + self.get_input_value("b", 0)
        time.sleep(self.get_input_value("delay", 0))
        self.outputs.result = result


class SumTask2(
    Task,
    input_names=["a"],
    optional_input_names=["b", "delay"],
    output_names=["result"],
):
    """Add two numbers"""

    def run(self):
        result = self.inputs.a + self.get_input_value("b", 0)
        time.sleep(self.get_input_value("delay", 0))
        self.outputs.result = result



import pytest
from ewokstomo.tasks.sumtask import SumTask, SumTask1, SumTask2


@pytest.mark.parametrize("Task", [SumTask, SumTask1, SumTask2])
def test_sum_task(Task):
    task = Task(inputs={"a": 1, "b": 2})
    task.run()
    assert task.outputs.result == 3
